<?php 

/**************************************************************
 *                                                            *
 *   Provides a notification to the user everytime            *
 *   your WordPress plugin is updated                         *
 *															  *
 *	 Based on the script by Unisphere:						  *
 *   https://github.com/unisphere/unisphere_notifier          *
 *                                                            *
 *   Author: Pippin Williamson                                *
 *   Profile: http://codecanyon.net/user/mordauk              *
 *   Follow me: http://twitter.com/pippinsplugins             *
 *                                                            *
 **************************************************************/
 
define( 'SUEVA_EK_PLUGIN_NAME', 'Sueva Essential Kit' );
define( 'SUEVA_EK_PLUGIN_MENUBAR', 'Sueva EK' );
define( 'SUEVA_EK_PLUGIN_FOLDER_NAME', 'sueva-essential-kit' );
define( 'SUEVA_EK_PLUGIN_FILE_NAME', 'init.php' );
define( 'SUEVA_EK_PLUGIN_XML_FILE', 'demo.themeinprogress.com/sueva/sueva-essential-kit.xml' );
define( 'SUEVA_EK_NOTIFIER_CACHE_INTERVAL', 21600 );

if (!function_exists('sueva_ek_notifier_menu')) {
	
	function sueva_ek_notifier_menu() {  
	
		if ( function_exists( 'simplexml_load_string' ) ) {
		   
			$xml 			= sueva_ek_plugin_version( SUEVA_EK_NOTIFIER_CACHE_INTERVAL );
			$plugin_data 	= @get_plugin_data( WP_PLUGIN_DIR . '/' . SUEVA_EK_PLUGIN_FOLDER_NAME . '/' . SUEVA_EK_PLUGIN_FILE_NAME );
			
			if ( (string) $xml->latest > (string) $plugin_data['Version'] ) {
				
				$menu_name = SUEVA_EK_PLUGIN_MENUBAR;
		
				add_dashboard_page( SUEVA_EK_PLUGIN_MENUBAR . ' Plugin Updates', $menu_name . ' <span class="update-plugins count-1"><span class="update-count">New Updates</span></span>', 'administrator', 'sueva-ek--plugin-update-notifier', 'sueva_ek_notifier');
	
			}
		
		}	
	
	}
	
	add_action('admin_menu', 'sueva_ek_notifier_menu');
	
}

if (!function_exists('sueva_ek_notifier')) {

	function sueva_ek_notifier() { 
	
		$xml 			= sueva_ek_plugin_version( SUEVA_EK_NOTIFIER_CACHE_INTERVAL );
		$plugin_data 	= @get_plugin_data( WP_PLUGIN_DIR . '/' . SUEVA_EK_PLUGIN_FOLDER_NAME . '/' .SUEVA_EK_PLUGIN_FILE_NAME );
	
	?>
	
		<style>
			.update-nag { display: none; }
			#instructions {max-width: 670px;}
			h3.title {margin: 30px 0 0 0; padding: 30px 0 0 0; border-top: 1px solid #ddd;}
		</style>
	
		<div class="wrap">
	
			<div id="icon-tools" class="icon32"></div>
			
            <h2><?php echo SUEVA_EK_PLUGIN_NAME ?> Plugin Updates</h2>
			<div id="message" class="updated below-h2"><p><strong>There is a new version of the <?php echo SUEVA_EK_PLUGIN_NAME; ?> plugin available.</strong> You have version <?php echo $plugin_data['Version']; ?> installed. Update to version <?php echo $xml->latest; ?>.</p></div>
			
			<div id="instructions">
				<h3>Update Download and Instructions</h3>
				<p><strong>Please note:</strong> make a <strong>backup</strong> of the Plugin inside your WordPress installation folder <strong>/wp-content/plugins/<?php echo SUEVA_EK_PLUGIN_FOLDER_NAME; ?>/</strong> and delete the previous version.</p>
				<p>To update the Plugin, login to <a href="https://www.themeinprogress.com">ThemeinProgress</a>, go to <strong>your purchases</strong> page and download again the Sueva Package, then get the installable file <strong>sueva_essential_kit.zip</strong> and re-install the plugin like you did when you bought it.</p>
				<p>If you didn't make any changes to the plugin files, you are free to overwrite them with the new ones without the risk of losing any plugins settings, and backwards compatibility is guaranteed.</p>
			</div>
			
			<h3 class="title">Changelog</h3>
			
			<?php echo $xml->changelog; ?>
	
		</div>
		
<?php 
	
	} 
	
}

if (!function_exists('sueva_ek_plugin_version')) {

	function sueva_ek_plugin_version( $interval ) {
		
		$notifier_file_url = SUEVA_EK_PLUGIN_XML_FILE;	
		$plugin_data 	= @get_plugin_data( WP_PLUGIN_DIR . '/' . SUEVA_EK_PLUGIN_FOLDER_NAME . '/' .SUEVA_EK_PLUGIN_FILE_NAME );
	
		$db_cache_field = $plugin_data['TextDomain'] . '-notifier-cache';
		$db_cache_field_last_updated = $plugin_data['TextDomain'] . '-notifier-cache-last-updated';
		$last = get_option( $db_cache_field_last_updated );
		$now = time();
	
		if ( ! $last || ( ( $now - $last ) > $interval ) ) {
	
			if( function_exists( 'curl_init' ) ) {
			
				$ch = curl_init( $notifier_file_url );
				curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
				curl_setopt( $ch, CURLOPT_HEADER, 0 );
				curl_setopt( $ch, CURLOPT_TIMEOUT, 10 );
				$cache = curl_exec( $ch );
				curl_close( $ch );
			
			} else {
			
				$cache = file_get_contents( $notifier_file_url );
			
			}
			
			if ( $cache ) {			
	
				update_option( $db_cache_field, $cache );
				update_option( $db_cache_field_last_updated, time() );
			} 
	
			$notifier_data = get_option( $db_cache_field );
		
		} else {
	
			$notifier_data = get_option( $db_cache_field );
		}
	
		if( strpos( (string) $notifier_data, '<notifier>' ) === false ) {
		
			$notifier_data = '<?xml version="1.0" encoding="UTF-8"?><notifier><latest>1.0</latest><changelog></changelog></notifier>';
		
		}
	
		$xml = simplexml_load_string( $notifier_data ); 
		return $xml;
		
	}

}

?>