<?php

/*
Plugin Name: Sueva Essential Kit
Plugin URI: https://www.themeinprogress.com
Description: Enable all features of Sueva theme.
Version: 1.0.2
Author: ThemeinProgress
Author URI: https://www.themeinprogress.com
License: GPLv3
*/

require_once dirname(__FILE__) . '/functions.php';

if( !class_exists( 'sueva_ek_init' ) ) {

	class sueva_ek_init {
	
		/**
		* Constructor
		*/
			 
		public function __construct(){
	
			add_action('plugins_loaded', array(&$this,'plugins_loaded'));
			add_action('wp_enqueue_scripts', array(&$this,'site_scripts') );
			add_action('widgets_init', array(&$this,'load_widgets') );
			add_action('admin_init', array(&$this, 'plugin_scripts'));
			add_action('customize_controls_enqueue_scripts', array(&$this, 'customize_scripts'));

		}

		/**
		* Plugin widgets
		*/
			 
		public function load_widgets() {
	
			register_widget( 'wip_bio_widget' );
			register_widget( 'wip_twitter_widget' );
			register_widget( 'sueva_cta_widget' );
			register_widget( 'sueva_slideshow_widget' );
			register_widget( 'sueva_news_widget' );
			register_widget( 'sueva_team_widget' );
			register_widget( 'sueva_testimonial_widget' );
			register_widget( 'sueva_portfolio_widget' );
			register_widget( 'sueva_services_widget' );
			register_widget( 'sueva_count_widget' );
			register_widget( 'sueva_contactform_widget' );

		}

		/**
		* Plugin setup
		*/
			 
		public function plugins_loaded() {
			
			load_plugin_textdomain( 'sueva-essential-kit', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');
			
			sueva_ek_require('core/includes/');
			sueva_ek_require('core/cptypes/');
			sueva_ek_require('core/oauth/');
			sueva_ek_require('core/widgets/');
			sueva_ek_require('core/shortcodes/');
			add_image_size  ( 'sueva_slick', 940, 600, TRUE ); 
			add_image_size  ( 'sueva_team', 350, 350, TRUE ); 
			add_image_size  ( 'sueva_testimonial', 150, 150, TRUE ); 

		}
		
		/**
		* Load scripts
		*/
			 
		public function site_scripts() {

			
			wp_enqueue_script( 'jquery' );

			wp_enqueue_script( "jquery-ui-core", array('jquery'));
			wp_enqueue_script( "jquery-ui-tabs", array('jquery'));
	
			wp_enqueue_script( 'sueva-scrollReveal',   plugins_url('/assets/js/sueva-ek-scrollReveal.min.js', __FILE__ ), array("jquery"), '20160910', true );
			wp_enqueue_script( 'sueva-ek-slick.min',   plugins_url('/assets/js/sueva-ek-slick.min.js', __FILE__ ), array('jquery'), '20160910', true );
			wp_enqueue_script( 'sueva-ek-isotope.min', plugins_url('/assets/js/sueva-ek-isotope.min.js', __FILE__ ), array('jquery'), '20160910', true );
			wp_enqueue_script( 'sueva-ek-jquery',      plugins_url('/assets/js/sueva-ek-jquery.js', __FILE__ ), array('jquery'), '20160910', true );
			wp_enqueue_style ( 'sueva-ek-slick',       plugins_url('/assets/css/sueva-ek-slick.css', __FILE__ ), array(), null );
			wp_enqueue_style ( 'sueva-ek-isotope',     plugins_url('/assets/css/sueva-ek-isotope.css', __FILE__ ), array(), null );
			wp_enqueue_style ( 'sueva-ek-style',       plugins_url('/assets/css/sueva-ek-style.css', __FILE__ ), array(), null );
		
		}

		/**
		 * Loads the admin scripts and styles
		 */
		 
		public function plugin_scripts() {
			
			global $wp_version, $pagenow;

			$file_dir = plugins_url('/core/assets/', __FILE__ );

			if ( $pagenow == 'widgets.php' ) {

				wp_enqueue_style( 'wp-color-picker' ); 
				wp_enqueue_style( 'sueva_ek_style', $file_dir.'css/sueva_ek_style.css', array(), null );

				wp_enqueue_media();
			 	wp_enqueue_script( 'sueva_ek_script', $file_dir.'js/sueva_ek_script.js',array('jquery','media-upload','thickbox','wp-color-picker'),'1.0',TRUE ); 

			 }

		}
		
		/**
		 * Loads the customize scripts and styles
		 */
		 
		public function customize_scripts() {
			
			global $wp_version, $pagenow;

			$file_dir = plugins_url('/core/assets/', __FILE__ );

			if ( $pagenow == 'customize.php' ) {

				wp_enqueue_style( 'wp-color-picker' ); 
				wp_enqueue_style( 'sueva_ek_style', $file_dir.'css/sueva_ek_style.css', array(), null );

				wp_enqueue_media();
				wp_enqueue_style( 'wp-color-picker' ); 

			 	wp_enqueue_script( 'sueva_ek_customize', $file_dir.'js/sueva_ek_customize.js',array('jquery','media-upload','thickbox','wp-color-picker'),'1.0',TRUE ); 

			 }

		}

	}

	new sueva_ek_init();

}

?>