<?php

/**
 * Provides a notification everytime the theme is updated
 * Original code courtesy of João Araújo of Unisphere Design - http://themeforest.net/user/unisphere
 */

if (!function_exists('sueva_update_notifier_menu')) {

	function sueva_update_notifier_menu() {  
		
		$xml = sueva_latest_theme_version(21600); 
		
		if(version_compare(sueva_theme_data('Version'), $xml->latest) == -1) {
		
			add_theme_page(sueva_theme_data('Name') . ' Theme Updates', sueva_theme_data('Name').'<span class="update-plugins count-1"><span class="update-count">1 Update</span></span>', 'read', strtolower(sueva_theme_data('Name')) . '-updates', 'sueva_update_notifier');
			
		}
		
	}  
	
	add_action('admin_menu', 'sueva_update_notifier_menu');

}

if (!function_exists('sueva_update_notifier_bar_menu')) {

	function sueva_update_notifier_bar_menu() {
	   
		if (function_exists('simplexml_load_string')) {
			global $wp_admin_bar, $wpdb;
		
			$xml = sueva_latest_theme_version(21600); 
			
			if ( ! is_object( $xml ) )
				return;
		
				if(version_compare(sueva_theme_data('Version'), $xml->latest) == -1) {
				$wp_admin_bar->add_menu( array( 'id' => 'update_notifier', 'title' => '<span> '.sueva_theme_data('Name').' <span id="ab-updates">1 Update</span></span>', 'href' => get_admin_url() . 'themes.php?page=' . strtolower(sueva_theme_data('Name')) . '-updates' ) );
			}
			
		}
		
	}
	
	add_action( 'admin_bar_menu', 'sueva_update_notifier_bar_menu', 1000 );
	
}

if (!function_exists('sueva_update_notifier')) {

	function sueva_update_notifier() { 
	
		$xml = sueva_latest_theme_version(21600); 
		
?>
	
		<style>
            .update-nag {display: none;}
            h3.title {margin: 30px 0 0 0; padding: 30px 0 0 0; border-top: 1px solid #ddd;}
        </style>
    
        <div class="wrap sueva_theme_update">
        
            <div id="icon-tools" class="icon32"></div>
            <h2><?php echo esc_html(sueva_theme_data('Name')) ?> Theme Updates</h2>
            
            <div id="message" class="updated below-h2"><p><strong>There is a new version of the <?php echo esc_html(sueva_theme_data('Name')); ?> theme available.</strong> You have version <?php echo esc_html(sueva_theme_data('Version')); ?> installed. Update to version <?php echo esc_attr($xml->latest); ?>.</p></div>
            
            <img src="<?php echo get_template_directory_uri() . '/screenshot.png'; ?>" />
            
            <div id="instructions" >
             
                <h3>Update Download and Instructions</h3>
				<p><strong>Please note:</strong> make a <strong>backup</strong> of the Theme inside your WordPress installation folder <strong>/wp-content/themes/<?php echo strtolower(esc_html(sueva_theme_data('Name'))); ?>/</strong></p>
				<p>To update the Theme, login to your account, head over to your <strong>downloads</strong> section and re-download the theme like you did when you bought it.</p>
				<p>Extract the zip's contents, look for the extracted theme folder, and after you have all the new files upload them using FTP to the <strong>/wp-content/themes/<?php echo strtolower(esc_html(sueva_theme_data('Name'))); ?>/</strong> folder overwriting the old ones (this is why it's important to backup any changes you've made to the theme files).</p>
				<p>If you didn't make any changes to the theme files, you are free to overwrite them with the new ones without the risk of losing theme settings, pages, posts, etc, and backwards compatibility is guaranteed.</p>
            
                <div class="clear"></div>
            
            <h3 class="title">Changelog</h3>
            
			<?php echo wp_filter_post_kses($xml->changelog); ?>
    
        </div>
        
<?php

	} 

}

if (!function_exists('sueva_latest_theme_version')) {

	function sueva_latest_theme_version($interval) {

		global $wp_filesystem;

		if (empty($wp_filesystem)) {
			require_once (ABSPATH . '/wp-admin/includes/file.php');
			WP_Filesystem();
		}

		$notifier_file_url = 'http://demo.themeinprogress.com/' . strtolower(sueva_theme_data('Name')) . '/' . strtolower(sueva_theme_data('Name')) . '.xml';

		$db_cache_field = sueva_theme_data('Name') . '-notifier-cache';
		$db_cache_field_last_updated = sueva_theme_data('Name') . '-notifier-last-updated';
		
		$last = get_option( $db_cache_field_last_updated );
		
		$now = time();
	
		if ( !$last || ( ( $now - $last ) > $interval ) ) {
	
			if ( ini_get('allow_url_fopen') ) {
						
				$cache = $wp_filesystem->get_contents( $notifier_file_url ); 

			} else {

				$ch = curl_init($notifier_file_url);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($ch, CURLOPT_HEADER, 0);
				curl_setopt($ch, CURLOPT_TIMEOUT, 10);
				curl_setopt ($ch, CURLOPT_USERAGENT, 'ANNA NOTIFIER');
				$cache = curl_exec($ch);
				curl_close($ch);
					
			}

			if ($cache) {			

				update_option( $db_cache_field, $cache );
				update_option( $db_cache_field_last_updated, time() );			
			}

			$notifier_data = get_option( $db_cache_field );
		}
		
		else {

			$notifier_data = get_option( $db_cache_field );
		}
		
		$xml = @simplexml_load_string($notifier_data); 
		
		return $xml;
		
	}
	
}

?>