<?php
 
if( !class_exists( 'sueva_option_panel' ) ) {

	class sueva_option_panel {
	
		/**
		 * Constructor
		 */
		 
		public function __construct( $fields = array() ) {

			$this->panel_fields = $fields;
			$this->theme_name = "sueva_theme_settings";

			add_action('admin_menu', array(&$this, 'admin_menu'));
			add_action('admin_init', array(&$this, 'save_option'));
			add_action('admin_init', array(&$this, 'theme_script'));

		}
		
		/**
		 * Create option panel menu
		 */
		 
		public function admin_menu() {
		
			add_theme_page( esc_html__('Sueva Options', 'sueva'), esc_html__('Sueva Options', 'sueva'), 'administrator',  'sueva_option_panel', array(&$this, 'sueva_option_panel'));
			add_theme_page( esc_html__('Get Features', 'sueva'), esc_html__('Get Features', 'sueva'), 'administrator',  'sueva_get_features', array(&$this, 'sueva_get_features'));
		}

		/**
		 * Loads the theme scripts and styles
		 */
		 
		public function theme_script() {
			
			 global $wp_version, $pagenow;
		
			 $file_dir = get_template_directory_uri()."/core/assets/";

			 if ( $pagenow == 'themes.php' ) {

				wp_enqueue_media();
				wp_enqueue_style( 'wp-color-picker' ); 

			 }

			 if ( $pagenow == 'themes.php' || $pagenow == 'post.php' || $pagenow == 'post-new.php' || $pagenow == 'edit.php' ) {

			 	wp_enqueue_style ( 'sueva_panel', $file_dir.'css/panel.css' ); 
			 	wp_enqueue_style ( 'sueva_panel_google_fonts', '//fonts.googleapis.com/css?family=Roboto');
			 	wp_enqueue_style ( 'sueva_panel_fontawesome', get_template_directory_uri() . '/assets/css/font-awesome.css');
				wp_enqueue_style( 'wp-color-picker' ); 

			 	wp_enqueue_script( "jquery-ui-core", array('jquery'));
			 	wp_enqueue_script( "jquery-ui-tabs", array('jquery'));
			 	wp_enqueue_script( "jquery-ui-sortable", array('jquery'));
			 	wp_enqueue_script( 'sueva_panel',  $file_dir.'js/panel.js',array('jquery', 'media-upload', 'thickbox', 'wp-color-picker'),'1.0', TRUE ); 
			
			 }
			 
			 if ( $pagenow == 'themes.php' || $pagenow == 'post.php' || $pagenow == 'post-new.php' || $pagenow == 'edit.php' || $pagenow == 'widgets.php' || $pagenow == 'customize.php' ) {

			 	wp_enqueue_style ( 'sueva_on_off', $file_dir.'css/on_off.css' );
			 	wp_enqueue_script( 'sueva_on_off', $file_dir.'js/on_off.js','3.5', '', TRUE); 
			
			 }

		}

		/**
		 * Message after the options saving
		 */
		 
		public function save_message () {
			
			global $message_action;
			
			if (isset($message_action)) :
				
				echo '<div id="message" class="updated fade message_save sueva_message"><p><strong>'.$message_action.'</strong></p></div>';
			
			endif;
			
		}
		
		/**
		 * Save custom sidebar function
		 */
		 
		public function save_sidebar() {
			
			global $message_action;
		
			$sueva_setting = get_option( $this->theme_name );
			
			if ( $sueva_setting != false ) :
					
				$sueva_setting = maybe_unserialize( $sueva_setting );
								
			else :
				
				$sueva_setting = array();
			
			endif;      

			$sidebarname = $_REQUEST['sidebar_type']. "_" . sanitize_text_field($_REQUEST['wip_sidebars']);

			if ( !empty($sidebarname) && empty($sueva_setting["wip_sidebars"]) ) {
				
				$sueva_sidebars = array( "wip_sidebars" => array ($sidebarname) );
				update_option( $this->theme_name, array_merge( $sueva_setting ,$sueva_sidebars) );
				$message_action = 'Sidebar saved successfully.';
			
			} else {
				
				$error = 0;
					
				foreach ($sueva_setting["wip_sidebars"] as $singlesidebar) { 
					
					if (empty($_REQUEST['wip_sidebars'])) { 
					
						$error++;
						$message_action = 'Name missing sidebar.';
					
					} else if ($singlesidebar == $sidebarname ) { 
						$error++;
						$message_action = 'Sidebar is already exist in the database.';
					
					} 
			
				} 
					
				if (!empty($sidebarname) && ( $error == 0 ) ) { 	
					
					$message_action = 'Sidebar saved successfully.';
					array_push ( $sueva_setting["wip_sidebars"] , $sidebarname );
					update_option( $this->theme_name, array_merge( $sueva_setting ,$sueva_setting["wip_sidebars"]) );
				
				}
		
			}

		}
		
		/**
		 * Save options function
		 */
		 
		public function save_option () {
			
			global $message_action, $wp_filesystem;

			if (empty($wp_filesystem)) {
				require_once (ABSPATH . '/wp-admin/includes/file.php');
				WP_Filesystem();
			}

			$sueva_setting = get_option( $this->theme_name );
			
			if ( $sueva_setting != false ) :
					
				$sueva_setting = maybe_unserialize( $sueva_setting );
								
			else :
				
				$sueva_setting = array();
			
			endif;      

			if (isset($_GET['action']) && ($_GET['action'] == 'download')) {

				header("Cache-Control: public, must-revalidate");
				header("Pragma: hack");
				header("Content-Type: text/plain");
				header('Content-Disposition: attachment; filename="sueva_options_backup.dat"');
				echo serialize($this->get_options());
				exit;

			}
			
			if (isset($_GET['action']) && ($_GET['action'] == 'reset_options')) {
				
				update_option('sueva_theme_settings','');
				wp_redirect(admin_url('themes.php?page=sueva_option_panel&tab=Backup'));
				exit;

			}
			
			if (isset($_POST['upload_backup']) && check_admin_referer('sueva_restore_options', 'sueva_restore_options')) {

				if ($_FILES["upload_file"]["error"] <= 0) {
					
					$options = unserialize($wp_filesystem->get_contents($_FILES["upload_file"]["tmp_name"]));
				
					if ($options) {
				
						foreach ($options as $option) {
							
							update_option( 'sueva_theme_settings' , unserialize(sanitize_text_field($option->option_value)));

						}
				
					}
				
				}

				wp_redirect(admin_url('themes.php?page=sueva_option_panel&tab=Backup'));
				exit;
		
			}

			if ( $this->sueva_request('sueva_themeaction') == "Add Sidebar" ) {
			
				$this->save_sidebar();

			} else if ( $this->sueva_request('sueva_themeaction') == "delete_sidebar" && $sueva_setting ) {
					
				$message_action = esc_html__('Sidebar deleted successfully.', 'sueva' );
				unset($sueva_setting["wip_sidebars"][$_REQUEST['key']]);
				
				update_option( $this->theme_name, $sueva_setting );

			} else if ( $this->sueva_request('sueva_themeaction') == "Save" ) {
						
				foreach ( $this->panel_fields as $element ) {
					
					if ( isset($element['tab']) && $element['tab'] == $_GET['tab'] ) {
							
						foreach ($element as $value ) {
	
							if ( isset( $_REQUEST['element-opened'] ) && $_REQUEST['element-opened'] == "Skins" ) {
	
								$get_skin = sueva_jsonfile("skins.json");
								
								if ( isset( $get_skin[$_REQUEST["wip_skins"]]) ) {

									$current = $get_skin[$_REQUEST["wip_skins"]];
									update_option( $this->theme_name, array_merge( $sueva_setting, $current ) );
									$message_action = esc_html__('Options saved successfully.','sueva');

								}
								
								break;
							
							} else if ( isset( $value['id']) && $value['id'] <> "wip_sidebars" ) {

								if ( isset( $value['type'] ) && $value['type'] == "multioptions" ) {

									if ( isset ( $_POST[$value["id"]] ) ) :
											
										$current[$value["id"]] = maybe_unserialize( $_POST[$value["id"]]);
														
									else :
										
										$current[$value["id"]] = array();
									
									endif;      

									update_option( $this->theme_name, array_merge( $sueva_setting, $current) );

								} else if ( isset( $value['type'] ) && $value['type'] == "textarea" ) {

									$current[$value["id"]] = stripslashes($_POST[$value["id"]]);
									update_option( $this->theme_name, array_merge( $sueva_setting, $current) );
								
								} else {
	
									$sanize_function = array(  
										"upload" => "esc_url",
										"url" => "esc_url",
										"email" => "is_email",
										"select" => "sanitize_text_field",
										"thumbs" => "sanitize_text_field",
										"text" => "sanitize_text_field",
										"on-off" => "sanitize_text_field",
										"color" => "sanitize_text_field"
									);
									
									if ( isset ( $sanize_function[$value["type"]]) ) {
		
										$current[$value["id"]] = call_user_func( $sanize_function[$value["type"]], $_POST[$value["id"]] );
										update_option( $this->theme_name, array_merge( $sueva_setting, $current) );
									
									}
		
								}
								
								$message_action = esc_html__('Options saved successfully.', 'sueva' );

							} 
	
						}
		
					}
	
				}
	
				if ( $_REQUEST['tab'] == "Fonts" ) {
								
					$googlefonts = get_option('wip_fontlist');
								
					if ( !$googlefonts || $googlefonts <> sueva_fontlist() ){
								
						update_option( $this->theme_name.'_fontlist', sueva_fontlist() );
						
					}
							
				}
	
			}
	
		}

		/**
		 * Get features section
		 */
		 
		function sueva_get_features() { ?>
		
            <h2> <?php echo sueva_theme_data('Name')." ". esc_html__( 'Avaiable Features','sueva'); ?> </h2>
                    
            <p style=" font-weight:bold; width:800px"> <?php esc_html_e( 'Now Sueva is 100% compatible with the GNU license, these are some features that you can include in Sueva theme, not present in the package because with them, is not possible make Sueva 100% compatible with the GNU license.','sueva'); ?> </p>
                    
            <p> <?php _e( 'You can download the features from <a href="http://wpinprogress.com/get-features/" target="_blank">www.wpinprogress.com/get-features/</a>, with the username and password that you have received after the payment.','sueva'); ?> </p>
                    
            <h3> <?php esc_html_e( '1) Revolution Slider.','sueva'); ?> </h3>
                    
            <ol>
                    
                <li><?php _e( 'Download and extract the plugin, from <a href="http://wpinprogress.com/get-features/" target="_blank">www.wpinprogress.com/get-features/</a>','sueva'); ?></li>
                <li><?php _e( 'Extract the archive <strong>"Sueva_package.zip"</strong>, after extract the archive <strong>"RevSlider_package.zip"</strong> and install and activate the plugin called <strong>"revslider.zip"</strong>, from Plugins => Add new => Upload ','sueva'); ?></li>
    
            </ol>

<?php 
    
		}

		/**
		 * Get options
		 */
		 
		public function get_options() {
		
			global $wpdb;
			return $wpdb->get_results("SELECT option_name, option_value FROM {$wpdb->options} WHERE option_name = '".$this->theme_name."'");
		
		}
		
		/**
		 * Request function
		 */
		 
		public function sueva_request($id) {
			
			if ( isset ( $_REQUEST[$id]) ) :
				return $_REQUEST[$id];	
			endif;
			
		}
		
		/**
		 * Option panel
		 */
		 
		public function sueva_option_panel() {

			global $message_action;

			if ( !isset($_GET['tab']) )  { 
			
				$_GET['tab'] = "General"; 
			
			}
			
			foreach ( $this->panel_fields as $element) {
		
				switch ( $element['type'] ) { 
				
					case 'navigation': ?>
						
						<div class="header">
							
							<div class="left">
							
								<a href="<?php echo esc_url('https://www.themeinprogress.com'); ?>" target="_blank">
							
									<img src="<?php echo esc_url(get_template_directory_uri().'/core/assets/images/logo.png'); ?>">
									
								</a>
							
							</div>
							
							<div class="theme_desc">
								
								<h2 class="maintitle"> 
		
									<?php echo esc_html__( 'Theme Details','sueva'); ?><br />
										
									<div class="theme_info"> <?php echo esc_html__( 'Current Theme: ','sueva') . sueva_theme_data( 'Name', false ); ?><br />
									<?php echo esc_html__( 'Version ','sueva') . ' ' . sueva_theme_data( 'Version', false ); ?></div>
		
								</h2>
								
							</div>
								
							<div class="clear"></div>
						
						</div>
						
						<?php $this->save_message();?>
						
						<div id="tabs" class="sueva_option_panel">
		
						<ul>
			
							<?php 
							
								foreach ($element['item'] as $option => $name ) {
								
									if (str_replace(" ", "", $option) == $_GET['tab'] ) { 
									
										$class = "class='ui-state-active'";
									
									} else { 
									
										$class = "";
									
									}
									
									echo "<li ".$class."><a href='".esc_url("themes.php?page=sueva_option_panel&tab=".str_replace(' ', '', $option))."'>".$name."</a></li>";
								
								}
							
							?>
						
							<li class="clear"></li>
						
						</ul>
					   
						<?php	
					
					break;
					
					case 'endpanel':  ?>
						
					</div>
						
					<?php break;
					
			}
		
			if (isset($element['tab'])) : 
			
			switch ( $element['tab'] ) { 
		
				case $_GET['tab']:  
		
					foreach ($element as $value) {
					
						if (isset($value['type'])) :
						
							switch ( $value['type'] ) { 
							
								case 'form':  ?>
									
									<div id="<?php echo str_replace(' ', '', $value['name']); ?>">
									<form method="post" enctype="multipart/form-data" action="?page=sueva_option_panel&tab=<?php echo esc_attr($_GET['tab']); ?>">
								
								<?php break;
								
								case 'endtab':  ?>
									
									</form>
									</div>
								
								<?php break;
									
								case 'start':  ?>
			
								<?php 
					
									$class = '';
									
									if ( 'Save' == $this->sueva_request('sueva_themeaction') && $value['val'] == $this->sueva_request('element-opened') )
										$class=" inactive"; ; 
						
								?>
			
									<div class="sueva_container">
					
									<h5 class="element<?php echo esc_attr($class); ?>" id="<?php echo esc_attr($value['val']); ?>"><?php echo esc_attr($value['name']); ?></h5>
						   
									<div class="sueva_mainbox"> 
					
								<?php break;
						
								case 'startopen':  ?>
						
									<div class="sueva_container">
					
									<h5 class="element-open"><?php echo esc_attr($value['name']); ?></h5>
						   
									<div class="sueva_mainbox sueva_openbox"> 
					
								<?php break;
						
								case 'end':  ?>
						
									</div>            
					
									</div>
					   
								<?php break;
					
								case 'multioptions': ?>
					
									<div class="sueva_inputbox">
                                    
										<div class="input-left">

                                            <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
										
                                        </div>
                                        
                                        <div class="input-right">
										
											<?php foreach ( $value['options'] as $val => $option ) { 
                            
                                                $checked = '';
                            
                                                if ( sueva_setting($value['id']) != false ) {
                            
                                                    foreach ( sueva_setting($value['id']) as $check ) { 
            
                                                    if ( $check == $val ) { 
                                                        
                                                        $checked = 'checked="checked"'; 
                                                        
                                                    } 
                                                        
                                                } 
                            
                                            } 
                                                
                                            ?> 
                            
                                                <p>
                                                    <input name="<?php echo esc_attr($value['id']); ?>[]" type="checkbox" value="<?php echo esc_attr($val); ?>" <?php echo esc_attr($checked); ?> />
                                                    <?php echo esc_attr($option); ?> 			
                                                </p> 
                                                
                                            <?php } ?>  
                                            
                                            <p> <?php echo esc_attr($value['desc']); ?> </p>
					
										</div>
                                        
                                        <div class="clear"></div>
                                        
									</div>
					
									<?php break;
		
									case 'pages': ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">
    
                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
    
                                            </div>
    
                                            <div class="input-right">

												<?php foreach ( $value['options'] as $page ) { 
                            
                                                $checked ='';
                            
                                                if ( sueva_setting($value['id']) != false ) {
                            
                                                    foreach (sueva_setting($value['id']) as $check ) { 
                            
                                                    if ($check == $page->ID )  { $checked ='checked="checked"'; } } 
                            
                                                } ?> 
                                  
                                                <p><input name="<?php echo esc_attr($value['id']); ?>[]" type="checkbox" value="<?php echo esc_attr($page->ID); ?>" <?php echo esc_attr($checked); ?> /> <?php echo esc_attr($page->post_title); ?></p>
                            
                                                <?php } ?>  
                                                
                                                <p><?php echo esc_attr($value['desc']); ?></p>
                         
                                            </div>
                                            
                                            <div class="clear"></div>
                                        
										</div>
					 
									<?php break;
									
									case 'thumbs': ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">
    
                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                            
                                            </div>
                                            
                                            <div class="input-right">
                                            
                                                <input name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="text" value="<?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" />
                                                
                                                <p> <?php echo esc_attr($value['desc']); ?> </p>
                        
                                            </div>
                                            
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break;
									
									case 'text': ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                                
                                            </div>

                                            <div class="input-right">

                                                <input name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="<?php echo esc_attr($value['type']); ?>" value="<?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" />
                                                <p> <?php echo esc_attr($value['desc']); ?> </p>
                                                
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break;
									
									case 'url': ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                                
                                            </div>

                                            <div class="input-right">

                                                <input name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="text" value="<?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" />
                                                <p> <?php echo esc_attr($value['desc']); ?> </p>
                                                
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break;
						
									case 'email': ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                                
                                            </div>

                                            <div class="input-right">

                                                <input name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="text" value="<?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" />
                                                <p> <?php echo esc_attr($value['desc']); ?> </p>
                                                
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break;
						
									case "upload": ?>
					
										<?php if (isset( $value['class'] )) { $up_class = ' ' . $value['class']; } ?>

										<div class="sueva_inputbox <?php echo esc_attr($up_class); ?>">  

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>

                                            </div>

                                            <div class="input-right">

                                                <input id="<?php echo esc_attr($value['id']); ?>" type="text" name="<?php echo esc_attr($value['id']); ?>" class="upload_attachment" value="<?php if ( sueva_setting($value['id']) != "") { echo esc_url(sueva_setting($value['id'])) ; } else { echo esc_attr($value['std']); } ?>" />
                                                
                                                <input type="button" name="upload_button" class="button upload_button" value="<?php esc_attr_e('Upload','sueva'); ?>" />
                             
                                                <p><?php echo esc_attr($value['desc']); ?></p>
                            
                                                <?php if ( sueva_setting($value['id']) != "") { echo "<img src='".esc_url(sueva_setting($value['id']))."' class='upload-preview' alt='image'/>"; } ?>
										
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break; 
									
									case 'form':  ?>
						
									<?php break;
						
									case 'navigation':  ?>
						
										<?php echo esc_attr($value['start']); ?>
					
										<?php foreach ($value['item'] as $option) { echo "<li><a href='#" . str_replace(" ", "", esc_attr($option))."'>" . esc_attr($option)."</a></li>"; } ?>
					
										<?php echo esc_attr($value['end']); ?>
					   
									<?php break;
					 
									case 'textarea':  ?>
						
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="bl_custom_style"> <?php echo esc_attr($value['name']); ?> </label>

                                            </div>

                                            <div class="input-right">

                                                <textarea name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="<?php echo esc_attr($value['type']); ?>" cols="" rows=""><?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?></textarea>
                            
                                                <p><?php echo esc_attr($value['desc']); ?></p>
                            
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
						
									<?php break;
					
									case "on-off": ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>

                                            </div>

                                            <div class="input-right">

                                                <div class="bool-slider <?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>">
                                                   
                                                    <div class="inset">
                                                    
                                                        <div class="control"></div>
                                                    
                                                    </div>
                                                    
                                                    <input name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" class="on-off" type="hidden" value="<?php if ( sueva_setting($value['id']) != "") { echo stripslashes(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" />
                                                
                                                </div>  
                                                
                                                <div class="clear"></div>      
                                                
                                                <p><?php echo esc_attr($value['desc']); ?></p>
										
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break;
						 
									case 'category': ?>
						
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                            
                                            </div>

                                            <div class="input-right">
                                            
                                                <select name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>"><?php foreach ($value['options'] as $option) { ?><option<?php if ( sueva_setting($value['id']) == get_cat_id($option)) { echo ' selected="selected"'; } elseif ($option == $value['std']) { echo ' selected="selected"'; } ?> value="<?php echo get_cat_id($option); ?>" ><?php echo esc_attr($option); ?></option><?php } ?></select>
                             
                                                <p><?php echo esc_attr($value['desc']); ?></p>
					
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
						
									<?php break;
						 
									case 'select': ?>
						
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                            
                                            </div>

                                            <div class="input-right">

                                                <select name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>">  
                                                
                                                <?php foreach ( $value['options'] as $val => $option ) { ?>  
                                                
                                                <option <?php if (( sueva_setting( $value['id'] ) == $val) || ( ( !sueva_setting($value['id'])) && ( $value['std'] == $val) )) { echo 'selected="selected"'; } ?> value="<?php echo esc_attr($val); ?>"><?php echo esc_attr($option); ?></option><?php } ?>  
                                                </select>  
                             
                                                <p><?php echo esc_attr($value['desc']); ?></p>
					
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
						
									<?php break;
									
									case "save-button": ?>
					
										<div class="sueva_inputbox">
					
										<input name="sueva_themeaction" id="element-open" type="submit" value="<?php echo esc_attr($value['value']); ?>" class="button save_button"/>
					
										</div>
					
									<?php break;
					 
									case "color": ?>
									
										<div class="sueva_inputbox">

                                            <div class="input-left">
                                                
                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>

                                            </div>

                                            <div class="input-right">

                                                <input type="text" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" value="<?php if ( sueva_setting($value['id']) != "") { echo esc_attr(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" data-default-color="<?php if ( sueva_setting($value['id']) != "") { echo esc_attr(sueva_setting($value['id'])); } else { echo esc_attr($value['std']); } ?>" class="sueva_color_picker" />

                                                <p><?php echo esc_attr($value['desc']); ?></p>
					
											</div>
					
                                            <div class="clear"></div>
                                        
										</div>
					
									<?php break;

									case 'viewsidebars': ?>
					
										<div class="sueva_inputbox_sidebars">
					
										<?php
					
											$sidebars = get_option($this->theme_name);
						
											if (!empty($sidebars[$value['sidebar']])) :
						
											foreach ($sidebars[$value['sidebar']] as $id => $singlesidebar) {  
											
											$sidebar_type = explode("_", $singlesidebar); ?>
										   
											<div class="delete">
											
												<a href="<?php echo esc_url('?page='.esc_attr($_GET['page']).'&tab=Sidebars&sueva_themeaction=delete_sidebar&key='.esc_attr($id).'#Sidebars'); ?>" alt="delete">
													<img src="<?php echo get_template_directory_uri('template_directory'); ?>/core/assets/images/close_16.png" alt="delete" />
												</a>
											
											</div>
						
											<div class="sidebar_list" >
												
												<?php 
												
													echo "<strong>" . esc_html__( 'Sidebar position','sueva').":</strong> " . ucfirst($sidebar_type[0]) . "<br /></strong>";
													echo "<strong>" . esc_html__( 'Sidebar name','sueva').":</strong> " . $sidebar_type[1];
													
												?>
					   
											</div>
						
											<div class="clear"></div>
											
											<?php }
						
											else :
												
												esc_html_e( 'No sidebar yet','sueva');
											
											endif;
					
											?>
					
											</div>
					
									<?php break;
									
									case 'sidebar': ?>
					
										<div class="sueva_inputbox">
                                        
                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['name']); ?></label>
                                           
                                            </div>

                                            <div class="input-right">

                                                <input name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="text" />
									   
                                            </div>
											
                                            <div class="clear"></div>

										</div>
		
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                            	<label for="<?php echo esc_attr($value['id']); ?>"><?php echo esc_attr($value['desc']); ?></label>
											
                                            </div>

                                            <div class="input-right">

                                                <select name="sidebar_type" id="sidebar_type" >  
                            
                                                <?php foreach ($value['options'] as $val => $option ) { ?>  
                                                    
                                                    <option <?php if ( sueva_setting($value['id']) == $val) { echo 'selected="selected"'; } ?> value="<?php echo esc_attr($val); ?>"><?php echo esc_attr($option); ?></option>							
                                                    
                                                <?php } ?>  
                                                
                                                </select>  
											
                                            </div>
											
                                            <div class="clear"></div>

										</div>
					
									<?php break;

									case 'import_export': ?>
					
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php esc_html_e( "Current theme settings","sueva"); ?></label>
                                            
                                            </div>

                                            <div class="input-right">
                                            
                                                <p><textarea class="widefat code" rows="20" cols="100" onclick="this.select()"><?php echo serialize($this->get_options()); ?></textarea></p>
                                                <a href="<?php echo esc_url('?page=sueva_option_panel&tab=Backup&action=download');?>" class="button button-secondary"><?php esc_html_e( "Download current theme settings","sueva"); ?></a>
									   
                                            </div>
											
                                            <div class="clear"></div>

										</div>
		
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php esc_html_e( "Reset theme settings","sueva"); ?></label>
                                            
                                            </div>

                                            <div class="input-right">

                                                <a href="<?php echo esc_url('?page=sueva_option_panel&tab=Backup&action=reset_options');?>" class="button-secondary"><?php esc_html_e( "Reset theme settings","sueva"); ?></a>
                                                <p><?php esc_html_e( "If you click the button above, the theme options return to its default values","sueva"); ?></p>
                                            
                                            </div>
											
                                            <div class="clear"></div>

										</div>
		
										<div class="sueva_inputbox">

                                            <div class="input-left">

                                                <label for="<?php echo esc_attr($value['id']); ?>"><?php esc_html_e( "Import theme settings","sueva"); ?></label>
                                            
                                            </div>

                                            <div class="input-right">
    
                                                <input type="file" name="upload_file" /> 
                                                <input type="submit" name="upload_backup" id="upload_backup" class="button-primary" value="<?php esc_html_e( "Import theme settings","sueva"); ?>" />	
                                                <?php if (function_exists('wp_nonce_field')) wp_nonce_field('sueva_restore_options', 'sueva_restore_options'); ?>
                                            
                                            </div>
											
                                            <div class="clear"></div>

										</div>
		
									<?php break;
								}
							
							endif;
						
						}
					
					}	
				
				endif;	
		
			}

		}
	
	}

}

?>