<?php

if( !class_exists( 'sueva_taxonomy_fields' ) ) {

	class sueva_taxonomy_fields{
	
		public $tax_fields;
	
		public function __construct( $tax_fields = array() ){
	
			$this->tax_fields = $tax_fields;
			
			foreach ( $tax_fields['taxonomies'] as $taxonomy_name ) {
	
				add_action( $taxonomy_name . '_add_form_fields', array( $this, 'add_tax_image_field' ) );
				add_action( $taxonomy_name . '_edit_form_fields', array( $this, 'edit_tax_image_field' ) );
				
				add_action( 'edited_' . $taxonomy_name , array( $this, 'save_tax_meta' ), 10, 2 );
				add_action( 'create_' . $taxonomy_name , array( $this, 'save_tax_meta' ), 10, 2 );
	
			}
			
		}
	 
		public function add_tax_image_field() { 
	
			$tax_fields = $this->tax_fields ;
	
			foreach ( $tax_fields['items'] as $value) {
	
				switch ( $value['type'] ) { 
	
					case 'upload' : ?>
	
						<div class="form-field taxonomy_input">
						
							<label for="sueva_taxmeta"><?php echo esc_attr($value['desc']); ?></label>
							<input type="text" class="idattachment" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" value="" />
							<input type="button" name="just_button" class="button" value="<?php esc_attr_e('Upload','sueva'); ?>" />
						
						</div>
	
				<?php
					
					break;
	
					case 'color' : ?>
					
						<div class="form-field taxonomy_input">
						
							<label for="sueva_taxmeta"><?php echo esc_attr($value['desc']); ?></label>
							<input data-hex="true" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="<?php echo esc_attr($value['type']); ?>" value="<?php echo esc_attr($value['std']); ?>"/>
						
						</div>
						
				<?php
					
					break;
	
					case 'select' : ?>
					
						<div class="form-field taxonomy_input">
						
							<label for="sueva_taxmeta"><?php echo esc_attr($value['desc']); ?></label>
	
							<select class="sueva_taxmeta_select" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" >
								
								<?php foreach ($value['options'] as $option => $values) { ?>
									
									<option <?php if ( $value['std'] == $option ) { echo 'selected="selected"'; } ?> value="<?php echo esc_attr($option); ?>"><?php echo esc_attr($values); ?></option>
								
								<?php } ?>  
	
							</select>
	
						</div>
						
				<?php
					
					break;
	
				}
				
			}
			
		} 
		
		public function edit_tax_image_field( $term ){
	
			$tax_fields = $this->tax_fields ;
	
			$sueva_taxmeta = get_option( "wip_taxmeta_" . $term->term_id );
			
			foreach ( $tax_fields['items'] as $value) {
	
				switch ( $value['type'] ) { 
	
					case 'upload' : ?>
	
						<tr class="form-field taxonomy_input">
							
							<th scope="row">
								
								<label for="sueva_taxmeta"><?php echo esc_attr($value['desc']); ?></label>
								
								<td>
									
									<input type="text" class="idattachment" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" value="<?php if ( $sueva_taxmeta[$value['id']] != "") { echo esc_attr($sueva_taxmeta[$value['id']]) ; } else { echo esc_attr($value['std']); } ?>" />
									<input type="button" name="just_button" class="button" value="<?php esc_attr_e('Upload','sueva'); ?>" />
								
								</td>
								
							</th>
							
						</tr>
	
				<?php
					
					break;
	
					case 'color' : ?>
	
						<tr class="form-field taxonomy_input">
							
							<th scope="row">
								
								<label for="sueva_taxmeta"><?php echo esc_attr($value['desc']); ?></label>
								
								<td>
	
									<input class="sueva_taxmeta_color" data-hex="true" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" type="<?php echo esc_attr($value['type']); ?>" value="<?php if ( $sueva_taxmeta[$value['id']] != "") { echo esc_attr($sueva_taxmeta[$value['id']]) ; } else { echo esc_attr($value['std']); } ?>" />
	
								</td>
								
							</th>
							
						</tr>
						
				<?php
					
					break;
	
					case 'select' : ?>
	
						<tr class="form-field taxonomy_input">
							
							<th scope="row">
								
								<label for="sueva_taxmeta"><?php echo esc_attr($value['desc']); ?></label>
								
								<td>
	
									<select class="sueva_taxmeta_select" name="<?php echo esc_attr($value['id']); ?>" id="<?php echo esc_attr($value['id']); ?>" >
										
										<?php foreach ($value['options'] as $option => $values) { ?>
											
											<option <?php if (( $sueva_taxmeta[$value['id']] == $option) || ( ( !$sueva_taxmeta[$value['id']] ) && ( $value['std'] == $option) )) { echo 'selected="selected"'; } ?> value="<?php echo esc_attr($option); ?>"><?php echo esc_attr($values); ?> </option>
	
										<?php } ?>  
			
									</select>

								</td>
								
							</th>
							
						</tr>
						
				<?php
					
					break;
	
				}
				
			}
	
		}
		
		public function save_tax_meta( $term_id ) {
	
			$tax_fields = $this->tax_fields;
	
			$sueva_taxmeta = get_option( 'wip_taxmeta_' . $term_id );

			if ( $sueva_taxmeta != false ) {
				
				$sueva_taxmeta = maybe_unserialize( $sueva_taxmeta );
				
			} else {
					
				$sueva_taxmeta = array();
				
			}      
	
			foreach ( $tax_fields['items'] as $value) {

				if ( isset($value['id']) && isset ($_POST[$value['id']] ) ) {

					$current[$value["id"]] = sanitize_text_field($_POST[$value["id"]]); 
					
				}
	
			}
			
			if ( isset($current) && is_array($current))
				update_option( 'wip_taxmeta_' . $term_id , array_merge( $sueva_taxmeta, $current) );
	 
		}
	 
	}
	
}
 
?>