<?php

/**
 * Wp in Progress
 * 
 * @package Wordpress
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * It is also available at this URL: http://www.gnu.org/licenses/gpl-3.0.txt
 */

/*-----------------------------------------------------------------------------------*/
/* Disable Isotope Plugin */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'sueva_disable_plugins' ) ) {

	function sueva_disable_plugins() {
		
		if ( is_plugin_active('wip-sueva-isotope/main.php') ) 
			deactivate_plugins('wip-sueva-isotope/main.php');    
		
		
		if ( is_plugin_active('suevafree-essential-kit/init.php') )
			deactivate_plugins('suevafree-essential-kit/init.php');    
		
	}
	
	add_action( 'admin_init', 'sueva_disable_plugins' );

}

/*-----------------------------------------------------------------------------------*/
/* Woocommerce is active */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'sueva_is_woocommerce_active' ) ) {
	
	function sueva_is_woocommerce_active( $type = "" ) {
	
        global $woocommerce;

        if ( isset( $woocommerce ) ) {
			
			if ( !$type || call_user_func($type) ) {
            
				return true;
			
			}
			
		}
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* TAG TITLE */
/*-----------------------------------------------------------------------------------*/  

if ( ! function_exists( '_wp_render_title_tag' ) ) {

	function sueva_title( $title, $sep ) {
		
		global $paged, $page;
	
		if ( is_feed() )
			return $title;
	
		$title .= get_bloginfo( 'name' );
		$site_description = get_bloginfo( 'description', 'display' );
		
		if ( $site_description && ( is_home() || is_front_page() ) )
			$title = "$title $sep $site_description";
		
		if ( $paged >= 2 || $page >= 2 )	
			$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'sueva' ), max( $paged, $page ) );

		return $title;
		
	}

	add_filter( 'wp_title', 'sueva_title', 10, 2 );

	function sueva_add_title() {
		
?>

	<title><?php wp_title( '|', true, 'right' ); ?></title>

<?php

	}

	add_action( 'wp_head', 'sueva_add_title' );

}

/*-----------------------------------------------------------------------------------*/
/* IS SINGLE */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_is_single')) {

	function sueva_is_single() {
		
		if ( is_single() || is_page() || is_singular('portfolio') ) :
		
			return true;
		
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* GET ARCHIVE TITLE */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_get_the_archive_title')) {

	function sueva_get_archive_title() {
		
		if ( is_category() ) {
			$title = sprintf( esc_html__( 'Category: %s', 'sueva' ), single_cat_title( '', false ) );
		} elseif ( is_tag() ) {
			$title = sprintf( esc_html__( 'Tag: %s', 'sueva' ), single_tag_title( '', false ) );
		} elseif ( is_author() ) {
			$title = sprintf( esc_html__( 'Author: %s', 'sueva' ), '<span class="vcard">' . get_the_author() . '</span>' );
		} elseif ( is_year() ) {
			$title = sprintf( esc_html__( 'Year: %s', 'sueva' ), get_the_date( esc_html_x( 'Y', 'yearly archives date format', 'sueva' ) ) );
		} elseif ( is_month() ) {
			$title = sprintf( esc_html__( 'Month: %s', 'sueva' ), get_the_date( esc_html_x( 'F Y', 'monthly archives date format', 'sueva' ) ) );
		} elseif ( is_day() ) {
			$title = sprintf( esc_html__( 'Day: %s', 'sueva' ), get_the_date( esc_html_x( 'F j, Y', 'daily archives date format', 'sueva' ) ) );
		} elseif ( is_tax( 'post_format' ) ) {
			if ( is_tax( 'post_format', 'post-format-aside' ) ) {
				$title = esc_html_x( 'Asides', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
				$title = esc_html_x( 'Galleries', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
				$title = esc_html_x( 'Images', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
				$title = esc_html_x( 'Videos', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
				$title = esc_html_x( 'Quotes', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
				$title = esc_html_x( 'Links', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
				$title = esc_html_x( 'Statuses', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
				$title = esc_html_x( 'Audio', 'post format archive title', 'sueva' );
			} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
				$title = esc_html_x( 'Chats', 'post format archive title', 'sueva' );
			}
		} elseif ( is_post_type_archive() ) {
			$title = sprintf( esc_html__( 'Archives: %s', 'sueva' ), post_type_archive_title( '', false ) );
		} elseif ( is_tax() ) {
			$tax = get_taxonomy( get_queried_object()->taxonomy );
			$title = sprintf( esc_html__( '%1$s: %2$s', 'sueva' ), $tax->labels->singular_name, single_term_title( '', false ) );
		}
	
		if ( isset($title) )  :
			return $title;
		else:
			return false;
		endif;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* SHORTCODES */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_clear_shortcodes')) {

	function sueva_clear_shortcodes ($content) {   
			
		$array = array (
			'<p>[' => '[', 
			']</p>' => ']', 
			']<br />' => ']'
		);
	
		$content = strtr($content, $array);
	
		return $content;
		
	}

	add_filter('the_content', 'sueva_clear_shortcodes');

}


/*-----------------------------------------------------------------------------------*/
/* THEMENAME */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_themename')) {

	function sueva_themename() {
		
		$themename = "sueva_theme_settings";
		return $themename;	
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* Theme settings */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_setting')) {

	function sueva_setting( $id, $default = '' ) {
	
		$sueva_setting = get_option(sueva_themename());
		
		if(isset($sueva_setting[$id])):
		
			return $sueva_setting[$id];
		
		else:
		
			return $default;
		
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* Post meta */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_postmeta')) {

	function sueva_postmeta( $id, $default = '' ) {
	
		global $post, $wp_query;
		
		if (sueva_is_woocommerce_active('is_shop')) :
	
			$content_ID = get_option('woocommerce_shop_page_id');
	
		else :
	
			$content_ID = $post->ID;
	
		endif;

		$val = get_post_meta( $content_ID , $id, TRUE);
		
		if ( !empty($val) ) :
			
			return $val;
			
		else:
				
			return $default;
			
		endif;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* TAX META */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_taxmeta')) {

	function sueva_taxmeta($id) {
		
		global $wp_query;
		
		if ( is_archive() || is_tax() || is_product_category() ) :
			
			$term_id = $wp_query->get_queried_object_id();
			$sueva_taxmeta = get_option('wip_taxmeta_' . $term_id);

			if ( isset( $sueva_taxmeta[$id] ) ) :
				
				return $sueva_taxmeta[$id];
			
			else:
			
				return false;
				
			endif;
			
		endif;	
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* REQUIRE */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_require')) {

	function sueva_require($folder) {
	
		if (isset($folder)) : 
		
			$dir = get_template_directory() . $folder ;  
				
			$files = scandir($dir);  
				  
			foreach ($files as $key => $value) {  

				if ( !in_array($value,array(".DS_Store",".","..") ) && !strstr( $value, '._' ) ) { 
						
					if ( !is_dir( $dir . $value) ) { 
							
						require_once $dir . $value;
						
					} 
					
				} 

			}  
				
		
		endif;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* SCRIPTS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_enqueue_script')) {

	function sueva_enqueue_script($folder) {
	
		if ( isset($folder) ) : 
	
			$dir = get_template_directory() . $folder ;  
				
			$files = scandir($dir);  
				  
			foreach ($files as $key => $value) {  

				if ( !in_array($value,array(".DS_Store",".","..") ) && !strstr( $value, '._' ) ) { 
						
					if ( !is_dir( $dir . $value ) && strstr ( $value, 'js' )) { 
							
						wp_enqueue_script( 'sueva-' . str_replace('.js','',$value), get_template_directory_uri() . $folder . "/" . $value , array('jquery'), FALSE, TRUE ); 
						
					} 
					
				} 

			}  

		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* STYLES */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_enqueue_style')) {

	function sueva_enqueue_style($folder) {
	
		if (isset($folder)) : 
	
			$dir = get_template_directory() . $folder ;  
				
			$files = scandir($dir);  
				  
			foreach ($files as $key => $value) {  

				if ( !in_array($value,array(".DS_Store",".","..") ) && !strstr( $value, '._' ) ) { 
						
					if ( !is_dir( $dir . $value ) && strstr ( $value, 'css' )) { 
						
						wp_enqueue_style( 'sueva-' . str_replace('.css','',$value), get_template_directory_uri() . $folder . "/" . $value ); 
						
					} 
					
				} 

			}  
			
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* PATH */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_theme_data')) {

	function sueva_theme_data($id, $check = true ) {
		
		if ( ( wp_get_theme()->parent() == true ) && ( $check == true ) ) {

			$themedata = wp_get_theme()->parent();

		} else if ( ( wp_get_theme()->parent() == false ) && ( $check == true ) ) {

			$themedata = wp_get_theme();

		} else if ( $check == false ) {

			$themedata = wp_get_theme();

		}

		return $themedata->get($id);
		
	}
	
}

/*-----------------------------------------------------------------------------------*/
/* VERSION */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_remove_version')) {

	function sueva_remove_version( $src ) {
	
		if ( strpos( $src, 'ver=' ) )
	
			$src = remove_query_arg( 'ver', $src );
	
		return $src;
	
	}

	add_filter( 'style_loader_src', 'sueva_remove_version', 9999 );
	add_filter( 'script_loader_src', 'sueva_remove_version', 9999 );

}

/*-----------------------------------------------------------------------------------*/
/*RESPONSIVE EMBED */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_embed_html')) {
	
	function sueva_embed_html( $html ) {
		return '<div class="embed-container">' . $html . '</div>';
	}
	 
	add_filter( 'embed_oembed_html', 'sueva_embed_html', 10, 3 );
	add_filter( 'video_embed_html', 'sueva_embed_html' );
	
}

/*-----------------------------------------------------------------------------------*/
/* BODY CLASSES */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_body_classes_function')) {

	function sueva_body_classes_function($classes) {

		global $wp_customize;

		if ( isset( $wp_customize ) ) :

			$classes[] = 'customizer_active';
				
		endif;

		if ( sueva_setting('wip_menu_layout') == "menubar" ) :
				
			$classes[] = 'menubar';
	
		endif;

		if ( sueva_setting('wip_header_layout') == "header_layout_2" ) :
				
			$classes[] = 'scroll_header';
	
		endif;

		if ( sueva_setting('wip_view_footer') == "off" ) :
				
			$classes[] = 'hide_footer';
	
		endif;

		if ( sueva_setting('wip_readmore_layout') == "sneak" ) :
				
			$classes[] = 'sneak_button';
	
		endif;

		if ( sueva_setting('wip_body_layout') == "minimal" ) :
				
			$classes[] = 'minimal_layout';
	
		endif;
		
		if ( sueva_setting('wip_footer_layout') == "footer_layout_2" ) :
				
			$classes[] = 'footer_layout_2';
	
		endif;
		
		if ( sueva_setting('wip_thumb_triangle') == "on" ) :
				
			$classes[] = 'thumb_triangle_off';
	
		endif;

		if ( sueva_setting('wip_thumb_hover') == "on" ) :
				
			$classes[] = 'thumb_hover_off';
	
		endif;
		
		if ( sueva_setting('wip_nicescroll') == "on" ) :
				
			$classes[] = 'nicescroll';
	
		endif;

		if ( !sueva_setting('wip_disable_box_shadow') || sueva_setting('wip_disable_box_shadow') == "on" ) :
				
			$classes[] = 'disable_box_shadow';
	
		endif;

		return $classes;
	
	}
	
	add_filter('body_class', 'sueva_body_classes_function');

}

/*-----------------------------------------------------------------------------------*/
/* POST CLASSES */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_post_classes_function')) {

	function sueva_post_classes_function( $classes ) {

		if ( sueva_is_woocommerce_active('is_cart') ) :
		
			$classes[] = 'woocommerce_cart_page';
				
		endif;

		return $classes;

	}

	add_filter( 'post_class', 'sueva_post_classes_function' );
	
}

/*-----------------------------------------------------------------------------------*/
/* CONTENT CLASS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_content_class')) {
	
	function sueva_content_class($id) {

		$class = array ( 
		
			"container" => "container-fluid" , 
			"row" => "row row-fluid" , 
		
		);

		if ( sueva_setting('wip_header_layout') == 'header_layout_8' ) :

			return $class[$id];

		else :

			return $id;

		endif;

	}
	 
}

/*-----------------------------------------------------------------------------------*/
/* Content template */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_template')) {

	function sueva_template($id) {
	
		$template = array ( 
		
			"full" => "col-md-12" , 
			"left-sidebar" => "col-md-8" , 
			"right-sidebar" => "col-md-8"
		
		);
	
		$span = $template["right-sidebar"];
		$sidebar =  "right-sidebar";

		if ( sueva_is_woocommerce_active('is_woocommerce') && ( sueva_is_woocommerce_active('is_product_category') || sueva_is_woocommerce_active('is_product_tag') ) && sueva_taxmeta('wip_woocommerce_taxonomy_layout') ) {
		
			$span = $template[esc_attr(sueva_taxmeta('wip_woocommerce_taxonomy_layout'))];
			$sidebar =  esc_attr(sueva_taxmeta('wip_woocommerce_taxonomy_layout'));

		} else if ( sueva_is_woocommerce_active('is_woocommerce') && is_search() && sueva_postmeta('wip_template') ) {
					
			$span = $template[esc_attr(sueva_postmeta('wip_template'))];
			$sidebar =  esc_attr(sueva_postmeta('wip_template'));
	
		} else if ( ( is_page() || is_single() || sueva_is_woocommerce_active('is_shop') ) && sueva_postmeta('wip_template') ) {
					
			$span = $template[esc_attr(sueva_postmeta('wip_template'))];
			$sidebar =  esc_attr(sueva_postmeta('wip_template'));

		} else if ( ! sueva_is_woocommerce_active('is_woocommerce') && ( is_category() || is_tag() || is_month() ) && sueva_setting('wip_category_layout') ) {

			$span = $template[esc_attr(sueva_setting('wip_category_layout'))];
			$sidebar =  esc_attr(sueva_setting('wip_category_layout'));
						
		} else if ( ! sueva_is_woocommerce_active('is_woocommerce') && ( is_tax('project') && !is_tax( 'post_format' ) && sueva_setting('wip_portfolio_layout')) ) {

			$span = $template[esc_attr(sueva_setting('wip_portfolio_layout'))];
			$sidebar =  esc_attr(sueva_setting('wip_portfolio_layout'));
						
		} else if ( is_home() && sueva_setting('wip_home') ) {
					
			$span = $template[esc_attr(sueva_setting('wip_home'))];
			$sidebar =  esc_attr(sueva_setting('wip_home'));

		} else if ( ! sueva_is_woocommerce_active('is_woocommerce') && is_search() && sueva_setting('wip_search_layout') ) {

			$span = $template[esc_attr(sueva_setting('wip_search_layout'))];
			$sidebar =  esc_attr(sueva_setting('wip_search_layout'));
						
		}

		return ${$id};
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* HOME BLOCK */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_block')) {

	function sueva_block( $id ) {
	
		$template = array ( 
			"block-two-colums" => "col-md-6" , 
			"block-three-colums" => "col-md-4" , 
			"block-four-colums" => "col-md-3" 
		);
		
		return $template[sueva_setting($id)];
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* SIDEBAR */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_sidebar_list')) {

	function sueva_sidebar_list( $sidebar_type) {
	
		$sueva_sidebars = get_option(sueva_themename());

		if ( $sidebar_type == "side" || $sidebar_type == "onepage" ) :

			$default = array( $sidebar_type."-sidebar-area" => "Default" );

		else:

			$default = array("none" => "None", $sidebar_type."-sidebar-area" => "Default");

		endif;
		
		$sidebar_list = array();
		
		if ( !empty($sueva_sidebars["wip_sidebars"]) ):
		
			foreach ($sueva_sidebars["wip_sidebars"] as $sidebar_item => $sidebar_items) {
				
				$sidebar = explode("_", $sidebar_items);

				if ($sidebar[0] == $sidebar_type)
					$sidebar_list[str_replace(" ","",strtolower($sidebar_items))] =  $sidebar[1];
					
			} 
				
			return array_merge($default, $sidebar_list);

		else:
			
			return $default;
			
		endif;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* GET SLIDERS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_slider_list')) {

	function sueva_slider_list() {
	
		if ( in_array( 'revslider/revslider.php' , get_option('active_plugins') ) ) {
			
			$sliders = array(
				"nivoslider" =>  esc_html__( "Nivo Slider","sueva"),
				"flexslider" =>  esc_html__( "Flex Slider","sueva"),
				"revsliders" =>  esc_html__( "Revolution Slider","sueva"),
			); 	
			
		} else {
			
			$sliders = array(
				"nivoslider" =>  esc_html__( "Nivo Slider","sueva"),
				"flexslider" =>  esc_html__( "Flex Slider","sueva"),
			); 	
			
		}
	
		return $sliders;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* GET REVOLUTION SLIDERS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_get_revsliders')) {

	function sueva_get_revsliders(){
		
		if ( in_array( 'revslider/revslider.php' , get_option('active_plugins') ) ) {
			
			if (class_exists('RevSlider')) {
				
				$theslider     = new RevSlider();
				$arrSliders = $theslider->getArrSliders();
				$arrA     = array();
				$arrT     = array();
				foreach($arrSliders as $slider){
					$arrA[]     = $slider->getAlias();
					$arrT[]     = $slider->getTitle();
				}
				if($arrA && $arrT){
					$result = array_combine($arrA, $arrT);
				}
				else
				{
					$result = false;
				}
				
				return $result;
			}
			
		} else {
			
			return array();
		
		}
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* GET PAGED */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_paged')) {

	function sueva_paged() {
		
		if ( get_query_var('paged') ) {
			$paged = get_query_var('paged');
		} elseif ( get_query_var('page') ) {
			$paged = get_query_var('page');
		} else {
			$paged = 1;
		}
		
		return $paged;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* Prettyphoto at post gallery */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_prettyPhoto')) {

	function sueva_prettyPhoto( $html, $id, $size, $permalink, $icon, $text ) {
		
		if ( ! $permalink )
			return str_replace( '<a', '<a data-rel="prettyPhoto" ', $html );
		else
			return $html;
	}

	add_filter( 'wp_get_attachment_link', 'sueva_prettyPhoto', 10, 6);

}

/*-----------------------------------------------------------------------------------*/
/* Excerpt more */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('sueva_hide_excerpt_more')) {

	function sueva_hide_excerpt_more() {
		return '';
	}

	add_filter('the_content_more_link', 'sueva_hide_excerpt_more');
	add_filter('excerpt_more', 'sueva_hide_excerpt_more');

}

/*-----------------------------------------------------------------------------------*/
/* Customize excerpt more */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('sueva_customize_excerpt_more')) {

	function sueva_customize_excerpt_more( $excerpt ) {
	
		global $post;
		
		if ( sueva_is_single() ) :
		
			return $excerpt;
		
		else :

			$allowed = array(
				'span' => array(
					'class' => array(),
				),
			);
	
			$class = 'button ' . sueva_setting('wip_readmore_layout');
			$button = esc_html__('Read More','sueva');
			$container = 'class="read-more"';
	
			if ( sueva_setting('wip_readmore_layout') == "default" || sueva_setting('wip_readmore_layout') == "sneak" || !sueva_setting('wip_readmore_layout') ) : 
			
				$class = 'button ' . sueva_setting('wip_readmore_layout');
				$button = esc_html__('Read More','wip');
				$container = 'class="read-more"';
	
			else :
	
				$class = 'nobutton';
				$button = ' [&hellip;] ';
				$container = '';
	
			endif;
		
			if ($pos=strpos($post->post_content, '<!--more-->')): 
			
				$content = substr(apply_filters( 'the_content', get_the_content()), 0, -5);
			
			else:
			
				$content = $excerpt;
			
			endif;
	
			return $content. '<a '. wp_kses($container, $allowed) . ' href="' . esc_url(get_permalink($post->ID)) . '" title="'.esc_html__('Read More','sueva').'"> <span class="'.esc_attr($class).'">'.$button.'</span></a>';

		endif;


	}
	
	add_filter( 'get_the_excerpt', 'sueva_customize_excerpt_more' );

}

/*-----------------------------------------------------------------------------------*/
/* Remove category list rel */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_remove_category_list_rel')) {

	function sueva_remove_category_list_rel($output) {
		$output = str_replace('rel="category"', '', $output);
		return $output;
	}

	add_filter('wp_list_categories', 'sueva_remove_category_list_rel');
	add_filter('the_category', 'sueva_remove_category_list_rel');

}

/*-----------------------------------------------------------------------------------*/
/* Remove thumbnail dimensions */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_remove_thumbnail_dimensions')) {

	function sueva_remove_thumbnail_dimensions( $html, $post_id, $post_image_id ) {
	
		$html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
		return $html;
	
	}

	add_filter( 'post_thumbnail_html', 'sueva_remove_thumbnail_dimensions', 10, 3 );

}
  
/*-----------------------------------------------------------------------------------*/
/* Remove css gallery */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_my_gallery_style')) {

	function sueva_my_gallery_style() {
		return "<div class='gallery'>";
	}

	add_filter( 'gallery_style', 'sueva_my_gallery_style', 99 );

}

/*-----------------------------------------------------------------------------------*/
/* POST ICON */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_posticon')) {

	function sueva_posticon() {
	
		$icons = array ( 
			"video" => "fa fa-play" , 
			"gallery" => "fa fa-camera" , 
			"audio" => "fa fa-volume-up" , 
			"chat" => "fa fa-users", 
			"status" => "fa fa-keyboard-o", 
			"image" => "fa fa-picture-o" ,
			"quote" => "fa fa-quote-left", 
			"link" => "fa fa-external-link", 
			"aside" => "fa fa-file-text-o", 
		);
	
		if ( get_post_format() ) { 
		
			$icon = '<span class="post-icon"><i class="'.$icons[get_post_format()].'"></i><span>' . ucfirst( strtolower( get_post_format() )) . '</span></span>'; 
		
		} else {
		
			$icon = '<span class="post-icon"><i class="fa fa-pencil-square-o"></i><span>' . esc_html__( "Article","sueva") . '</span></span>'; 
		
		}

		return $icon;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* JSON */
/*-----------------------------------------------------------------------------------*/  

if (!function_exists('sueva_jsonfile')) {
	
	function sueva_jsonfile( $url ) {
		
		global $pagenow, $wp_filesystem;
		
		if ( $pagenow == 'themes.php' ) {

			if (empty($wp_filesystem)) {
				require_once (ABSPATH . '/wp-admin/includes/file.php');
				WP_Filesystem();
			}
	
			if ( ini_get('allow_url_fopen') ) {
						
				$file_content = $wp_filesystem->get_contents( get_template_directory_uri() . '/core/admin/json/' . $url );
		
			} else {
					
				$ch = curl_init();
				curl_setopt ($ch, CURLOPT_URL, get_template_directory_uri() . '/core/admin/json/' . $url );
				curl_setopt ($ch, CURLOPT_SSL_VERIFYPEER, false);  
				curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, 10);
				curl_setopt ($ch, CURLOPT_USERAGENT, 'SUEVA JSONFILE');
				$file_content = curl_exec($ch);
				curl_close($ch);
					
			}
	
			return json_decode( $file_content, true );
		
		} else { 
		
			return false;
		
		}
		
	}
	
}

/*-----------------------------------------------------------------------------------*/
/* GOOGLE FONTS */
/*-----------------------------------------------------------------------------------*/  
 
if (!function_exists('sueva_get_font')) {
	
	function sueva_get_font( $name, $type) {

		global $pagenow;

		if ( $pagenow == 'themes.php' ) {
	
			$jsonfile = sueva_jsonfile("googlefonts.json");
			
			if ( $jsonfile['items'] != false ) :
					
				$fontsarray = maybe_unserialize( $jsonfile['items'] );
								
			else :
				
				$fontsarray = array();
			
			endif;      
	
			if (!function_exists('sueva_variants')) {
	
				function sueva_variants( $array ) {
				  
					$search = array( 
					
						"regular" => "400", 
						"italic" => "400italic" 
					
					);
					
					foreach ( $search as $key => $val ) {
					
						if ( in_array( $key, $array)) {
							
							$array[ array_search( $key, $array )]= $val; 
						
						}
						
					}
				
					return $array;
				
				}
			
			}
			
			foreach ( $fontsarray as $font ) {
			
				$getfont[$font['family']] = implode( ",", sueva_variants( $font['variants']));
				$getlist[$font['family']] = $font['family'];
	
			}
			
			if ( $type == "getfont" ) :
			
				return $getfont[$name];
			
			else:
			
				return $getlist;
			
			endif;
				
		}
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* FONT LIST */
/*-----------------------------------------------------------------------------------*/  
 
if (!function_exists('sueva_fontlist')) {
	
	function sueva_fontlist() {

		global $pagenow;

		if ( $pagenow == 'themes.php' ) {
		
			$fontsarray = array (
				
				'Raleway', 
				'Allura', 
				'Roboto', 
	
				esc_attr(sueva_setting("wip_logo_font")), 
				esc_attr(sueva_setting("wip_menu_font")), 
				esc_attr(sueva_setting("wip_logo_description_font")), 
				esc_attr(sueva_setting("wip_titles_font")),
				esc_attr(sueva_setting("wip_content_font"))
				
			);
			
			$fonts = array_unique($fontsarray); 
			
			foreach ( $fonts as $fontname ) {
				
				if ($fontname) { 
					
					$fontlist[] = str_replace(" ","+", $fontname) . ":" . sueva_get_font( $fontname, "getfont" ); 
				
				}
		
			}
	
			return implode( "|", $fontlist);
		
		}
		
	}
	
}

/*-----------------------------------------------------------------------------------*/
/* ICON LIST */
/*-----------------------------------------------------------------------------------*/  
 
if ( ! function_exists( 'sueva_iconlist' ) ) {
	
	function sueva_iconlist() {
	
		global $wp_filesystem;

		$pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"(.+)";\s+}/';
		
		if (empty($wp_filesystem)) {
			require_once (ABSPATH . '/wp-admin/includes/file.php');
			WP_Filesystem();
		}
	
		if ( ini_get('allow_url_fopen') ) {
						
			$file_content = $wp_filesystem->get_contents( get_template_directory_uri() . '/assets/css/font-awesome.css' );
		
		} else {
					
			$ch = curl_init();
			curl_setopt ($ch, CURLOPT_URL, get_template_directory_uri() . '/assets/css/font-awesome.css');
			curl_setopt ($ch, CURLOPT_SSL_VERIFYPEER, false);  
			curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, 10);
			curl_setopt ($ch, CURLOPT_USERAGENT, 'SUEVA FONT AWESOME ICONS');
			$file_content = curl_exec($ch);
			curl_close($ch);
		
		}
	
		preg_match_all($pattern, $file_content, $matches, PREG_SET_ORDER);
		
		$icons = array();
		
		sort($matches);
		
		foreach($matches as $match){
			$icons[$match[1]] = ucfirst(str_replace('fa-','',$match[1]));
		}
		
		return $icons;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* DEFAULT STYLE, AFTER THEME ACTIVATION */
/*-----------------------------------------------------------------------------------*/         

if ( ! function_exists( 'sueva_after_switch_theme' ) ) {

	function sueva_after_switch_theme () {
				
		$sueva_setting = get_option(sueva_themename());

		if (!$sueva_setting) {	

			update_option( sueva_themename(), sueva_jsonfile("default.json") ); 

		}

		$googlefonts = get_option('wip_fontlist');
								
		if ( !$googlefonts || $googlefonts <> sueva_fontlist() ){
								
			update_option( sueva_themename().'_fontlist', sueva_fontlist() );
						
		}

	}
	
	add_action('after_switch_theme', 'sueva_after_switch_theme');
	
}

/*-----------------------------------------------------------------------------------*/
/* THUMBNAIL WIDTH */
/*-----------------------------------------------------------------------------------*/         

if (!function_exists('sueva_get_width')) {

	function sueva_get_width() {
		
		if (sueva_setting('wip_screen3')):
		
			return esc_attr(sueva_setting('wip_screen3'));
		
		else:
		
			return "1170";
		
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* THUMBNAIL HEIGHT */
/*-----------------------------------------------------------------------------------*/         

if (!function_exists('sueva_get_thumbs')) {

	function sueva_get_thumbs($type) {
		
		if (sueva_setting('wip_'.$type.'_thumbinal')):
		
			return esc_attr(sueva_setting('wip_'.$type.'_thumbinal'));
		
		else:
		
			return "600";
		
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* WIDGETS WITHOUT PADDING */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_widget_class')) {

	function sueva_widget_class( $params ) {
		
		$name = $params[0]['widget_name'];
		
		$check = array(
			"Instagram Slider",
			"Revolution Slider",
			"Sueva Google Maps Widget",
			"Sueva Banner Widget",
			"Sueva Biography Widget",
			"Sueva Slick Slideshow",
			"Sueva Call To Action",
			"Sueva Team Slideshow",
			"Sueva Testimonial Slideshow",
			"Sueva Portfolio Widget",
			"Sueva News Slideshow",
			"Sueva Services Widget",
			"Sueva Contact Form Widget",
			"Sueva Counter Widget"
			
		);
		
		foreach ( $check as $value ) {
			
			if ( $value == $name ) : 

				$params[0]['before_widget'] = preg_replace( '/class="post-article/', 'class="no-padding', $params[0]['before_widget'], 1 );
			
			endif; 
			
		}
		
		return $params;
	}

	add_filter( 'dynamic_sidebar_params', 'sueva_widget_class' );

}

/*-----------------------------------------------------------------------------------*/ 
/* STYLES AND SCRIPTS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sueva_scripts_styles')) {

	function sueva_scripts_styles() {

		$header_layout = sueva_setting( 'wip_header_layout', 'header_layout_1');

		wp_enqueue_style( 'sueva_style', get_stylesheet_uri(), array() );

		$fonts_args = array(
			'family' => str_replace('|', '%7C', get_option( sueva_themename().'_fontlist', 'Cinzel+Decorative|Merriweather|Playfair+Display')),
			'subset' => esc_attr( implode(',' , sueva_setting('wip_charset', array('latin,latin-ext'))) )
		);
		
		wp_enqueue_style( 'sueva_google_fonts', add_query_arg ( $fonts_args, "https://fonts.googleapis.com/css" ), array(), null );
	
		sueva_enqueue_style('/assets/css');

		wp_enqueue_style( 'sueva-' . $header_layout , get_template_directory_uri() . '/assets/css/header/' . $header_layout . '.css' ); 
		
		wp_enqueue_script( "jquery-ui-core", array('jquery'));
		wp_enqueue_script( "jquery-ui-tabs", array('jquery'));

		sueva_enqueue_script('/assets/js');
	
		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );
		
		wp_enqueue_script('jquery');
		 
		wp_enqueue_script ( 'sueva-html5', get_template_directory_uri().'/assets/scripts/html5.js');
		wp_script_add_data ( 'sueva-html5', 'conditional', 'IE 8' );
		
		wp_enqueue_script ( 'sueva-selectivizr', get_template_directory_uri().'/assets/scripts/selectivizr-min.js');
		wp_script_add_data ( 'sueva-selectivizr', 'conditional', 'IE 8' );

	}

	add_action( 'wp_enqueue_scripts', 'sueva_scripts_styles' );

}

/*-----------------------------------------------------------------------------------*/
/* THEME SETUP */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_setup')) {

	function sueva_setup() {
		
		global $content_width;

		if ( ! isset( $content_width ) )
			$content_width = sueva_get_width();
		
		load_theme_textdomain( 'sueva', get_template_directory() . '/languages');
	
		add_filter('widget_text', 'do_shortcode');

		add_theme_support( 'post-formats', 
			
			array( 
				'aside',
				'gallery',
				'quote',
				'video',
				'audio',
				'link',
				'status',
				'chat',
				'image'
			)
		
		);
		
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'woocommerce' );

		add_theme_support( 'title-tag' );

		add_theme_support( 'custom-background', array(
			'default-color' => 'f3f3f3',
		) );

		add_theme_support( 'custom-header', array( 
			'default-image' => get_template_directory_uri() . '/assets/images/background/header.jpg'
		) );

		add_image_size( 'sueva_blog_thumbnail', sueva_get_width(), sueva_get_thumbs('blog'), TRUE ); 
		add_image_size( 'sueva_portfolio_thumbnail', sueva_get_width(),sueva_get_thumbs('portfolio'), TRUE ); 
		add_image_size( 'sueva_slick', sueva_get_width(),sueva_get_thumbs('portfolio'), TRUE ); 

		add_image_size( 'sueva_large', 449,304, TRUE ); 
		add_image_size( 'sueva_medium', 290,220, TRUE ); 
		add_image_size( 'sueva_small', 211,150, TRUE ); 

		register_nav_menu( 'main-menu', 'Main menu' );
		register_nav_menu( 'one-page-menu', 'One Page menu' );

		sueva_require('/core/post-formats/');
		sueva_require('/core/widgets/');
		
		sueva_require('/core/templates/header/');
		sueva_require('/core/templates/content/');
		sueva_require('/core/templates/sidebar/');
		sueva_require('/core/templates/footer/');
		sueva_require('/core/includes/');
		sueva_require('/core/functions/');
		sueva_require('/core/metaboxes/');
		sueva_require('/core/sliders/');

		if ( is_admin() == 1 )
			require_once get_template_directory() . '/core/admin/panel.php';
	
	}

	add_action( 'after_setup_theme', 'sueva_setup' );

}

/*-----------------------------------------------------------------------------------*/
/* DASHBOARD MENU */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sueva_dashboard_menu')) {

	function sueva_dashboard_menu() {
				
		global $wp_admin_bar, $wpdb;
				
		$wp_admin_bar->add_menu( array( 'id' => 'sueva_options', 'title' => '<span> '.esc_html__('Sueva Options', 'sueva').' </span>', 'href' => get_admin_url() . 'themes.php?page=sueva_option_panel' ) );
		$wp_admin_bar->add_menu( array( 'id' => 'sueva_features', 'title' => '<span> '.esc_html__('Get Features', 'wip').' </span>', 'href' => get_admin_url() . 'themes.php?page=sueva_get_features' ) );

	}

	add_action('admin_bar_menu', 'sueva_dashboard_menu', 1000 );

}

?>