<?php
/**
 * Cart Page
 *
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.3.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>

<div class="container-fluid">

    <div class="row">

		<form action="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" method="post">

        <div class="col-md-8">
        
        	<div class="woocommerce_cart_details">
        
                <h2 class="title"> <?php esc_html_e('Cart','sueva');?> </h2>
                
                <?php do_action( 'woocommerce_before_cart_table' ); ?>
                
                <table class="shop_table cart" cellspacing="0">
                    <thead>
                        <tr>
                            <th class="product-remove">&nbsp;</th>
                            <th class="product-thumbnail">&nbsp;</th>
                            <th class="product-name"><?php esc_html_e( 'Product', 'sueva' ); ?></th>
                            <th class="product-price"><?php esc_html_e( 'Price', 'sueva' ); ?></th>
                            <th class="product-quantity"><?php esc_html_e( 'Quantity', 'sueva' ); ?></th>
                            <th class="product-subtotal"><?php esc_html_e( 'Total', 'sueva' ); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php do_action( 'woocommerce_before_cart_contents' ); ?>
                
                        <?php
                        foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                            $_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                            $product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
                
                            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                ?>
                                <tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
                
                                    <td class="product-remove">
                                        <?php
                                            echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf( '<a href="%s" class="remove" title="%s">&times;</a>', esc_url( WC()->cart->get_remove_url( $cart_item_key ) ), esc_html__( 'Remove this item', 'sueva' ) ), $cart_item_key );
                                        ?>
                                    </td>
                
                                    <td class="product-thumbnail">
                                        <?php
                                            $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
                
                                            if ( ! $_product->is_visible() ) {
                                                echo esc_url($thumbnail);
                                            } else {
                                                printf( '<a href="%s">%s</a>', esc_url( $_product->get_permalink( $cart_item ) ), $thumbnail );
                                            }
                                        ?>
                                    </td>
                
                                    <td class="product-name">
                                        <?php
                                            if ( ! $_product->is_visible() ) {
                                                echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
                                            } else {
                                                echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s </a>', esc_url( $_product->get_permalink( $cart_item ) ), $_product->get_title() ), $cart_item, $cart_item_key );
                                            }
                
                                            // Meta data
                                            echo WC()->cart->get_item_data( $cart_item );
                
                                            // Backorder notification
                                            if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                                echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'sueva' ) . '</p>';
                                            }
                                        ?>
                                    </td>
                
                                    <td class="product-price">
                                        <?php
                                            echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                                        ?>
                                    </td>
                
                                    <td class="product-quantity">
                                        <?php
                                            if ( $_product->is_sold_individually() ) {
                                                $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                            } else {
                                                $product_quantity = woocommerce_quantity_input( array(
                                                    'input_name'  => "cart[{$cart_item_key}][qty]",
                                                    'input_value' => $cart_item['quantity'],
                                                    'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
                                                    'min_value'   => '0'
                                                ), $_product, false );
                                            }
                
                                            echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key );
                                        ?>
                                    </td>
                
                                    <td class="product-subtotal">
                                        <?php
                                            echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
                                        ?>
                                    </td>
                                </tr>
                                <?php
                            }
                        }
                
                        do_action( 'woocommerce_cart_contents' );
                        ?>
                        <tr>
                            <td colspan="6" class="actions">
                
                                <?php if ( WC()->cart->coupons_enabled() ) { ?>
                                    
                                    <div class="coupon">
                
                                        <label for="coupon_code"><?php esc_html_e( 'Coupon', 'sueva' ); ?>:</label> <input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_html_e( 'Coupon code', 'sueva' ); ?>" /> <input type="submit" class="button" name="apply_coupon" value="<?php esc_html_e( 'Apply Coupon', 'sueva' ); ?>" />
                
                                        <?php do_action( 'woocommerce_cart_coupon' ); ?>
                                        
                                        <div class="clear"></div>
                                        
                                    </div>
                                    
                                <?php } ?>
                
                                <?php do_action( 'woocommerce_cart_actions' ); ?>
                
                                <?php wp_nonce_field( 'woocommerce-cart' ); ?>
                            </td>
                        </tr>
                
                        <?php do_action( 'woocommerce_after_cart_contents' ); ?>
                    </tbody>
                </table>
                
                <?php 
				
					do_action( 'woocommerce_after_cart_table' );

					if ( sueva_postmeta('wip_view_social_buttons') == "on" ) :
					
						do_action('sueva_socialshare');
						
					endif;
					
				?>
                
            </div>
        
        </div>
    
        <div class="col-md-4 cart-total">
        
            <div class="cart-collaterals">
            
                <?php do_action( 'woocommerce_cart_collaterals' ); ?>
            
            </div>
        
        </div>

		</form>

    </div>

</div>

<?php do_action( 'woocommerce_after_cart' ); ?>
